package Apache::AxKit::GzConfigReader;

use strict;
use Apache::AxKit::ConfigReader;
@Apache::AxKit::GzConfigReader::ISA = qw( Apache::AxKit::ConfigReader );

$Apache::AxKit::GzConfigReader::VERSION = '1.01';

################################################################################
sub DoGzip {
    my $self = shift;
    return 1 if $self->SUPER::DoGzip();
    my $r = $self->{apache};
    my $encoding = $r->content_encoding();
    if ( defined $encoding and ( $encoding eq 'gzip' or $encoding eq 'x-gzip') )
    {
	# Unset content-encoding (set by AddEncoding for gzipped input).
	$r->content_encoding( undef );
    }
    return;
}

################################################################################
sub GunzipInput {
    my $self = shift;
    return '.gz'; # TODO: make this a real config variable?
#    return $self->{cfg}{GunzipInput}
#        || $self->{apache}->dir_config('AxGunzipInput');
}

################################################################################
sub DoGunzip {
    # does this filename have the gzip extension and should I gunzip it?
    my $self = shift;
    my $file = shift;

    my $gzextension = $self->GunzipInput();
    return unless defined $gzextension;
    $gzextension = ".$gzextension" unless substr( $gzextension, 0, 1 ) eq '.';
    my $extension = substr( $file, -length( $gzextension ) );
    return 1 if lc $extension eq lc $gzextension;
    return 0;
}

1;

__END__

=pod

=head1 NAME

Apache::AxKit::GzConfigReader - read gzipped input files

=head1 SYNOPSIS

In httpd.conf:

    AddEncoding x-gzip gz
    AxConfigReader Apache::AxKit::GzConfigReader
    AxProvider Apache::AxKit::Provider::GzFile

=head1 DESCRIPTION

This module allows gzipped input files to be read, for example
.xml.gz, .xsl.gz, and .xsp.gz.

If the Apache mod_gzip module is being used, then the "AddEncoding
x-gzip gz" directive tells it to recognize gzipped input files when a
non-gzipped input file is requested but is not available.  This
directive also adds the "Content-Encoding: gzip" HTTP header.  This
module, GzConfigReader, must strip out the content-encoding header
unless AxGzipOutput is turned on.

This module also provides methods for determining if a file needs to
be gunzipped by looking at its extension (.gz by default).

=head1 SEE ALSO

L<Apache::AxKit::Provider::GzFile|Apache::AxKit::Provider::GzFile>

=head1 AUTHOR

Ken Neighbors <ken@nsds.com>

=head1 COPYRIGHT and LICENSE

Copyright (c) 2002 Ken Neighbors

This module is licensed under the same terms as AxKit itself.

=cut
