package Apache::AxKit::Provider::GzFile;

use strict;
use Apache::AxKit::Exception;
use Compress::Zlib ();
use AxKit;
use Apache::AxKit::Provider::File;
@Apache::AxKit::Provider::GzFile::ISA = qw( Apache::AxKit::Provider::File );

$Apache::AxKit::Provider::GzFile::VERSION = '1.01';

################################################################################
sub get_fh {
    my $self = shift;
    my $filename = AxKit::FromUTF8( $self->{file} ); # FIXME: is this necessary?
    if ( $self->exists() and not $self->_is_dir()
	 and $AxKit::Cfg->DoGunzip( $filename ) )
    {
	throw Apache::AxKit::Exception::IO( -text =>
					    "$self->{file} is gzipped" );
    }
    $self->SUPER::get_fh();
}

################################################################################
sub get_strref {
    my $self = shift;
    my $filename = AxKit::FromUTF8( $self->{file} ); # FIXME: is this necessary?
    if ( $AxKit::Cfg->DoGunzip( $filename ) ) {
	my $fh = $self->SUPER::get_fh();
	local $/;
	my $contents = Compress::Zlib::memGunzip( <$fh> );
	return \$contents
    }
    $self->SUPER::get_strref();
}

1;

__END__

=pod

=head1 NAME

Apache::AxKit::Provider::GzFile - read gzipped input files

=head1 SYNOPSIS

In httpd.conf:

    AddEncoding x-gzip gz
    AxConfigReader Apache::AxKit::GzConfigReader
    AxProvider Apache::AxKit::Provider::GzFile

=head1 DESCRIPTION

This module allows gzipped input files to be read, for example
.xml.gz, .xsl.gz, and .xsp.gz.  This module, GzFile, uses
Compress::Zlib to gunzip such an input file.

If the Apache mod_gzip module is being used, then the "AddEncoding
x-gzip gz" directive tells it to recognize gzipped input files when a
non-gzipped input file is requested but is not available.

=head1 SEE ALSO

L<Apache::AxKit::GzConfigReader|Apache::AxKit::GzConfigReader>

=head1 AUTHOR

Ken Neighbors <ken@nsds.com>

=head1 COPYRIGHT and LICENSE

Copyright (c) 2002 Ken Neighbors

This module is licensed under the same terms as AxKit itself.

=cut
